DependencyTimelineView<T> class
Interactive dependency map with deterministic topological layers.
The view uses one static connector painter and regular positioned widgets. It creates no ticker and remains idle until data or selection changes.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DependencyTimelineView
Constructors
-
DependencyTimelineView({required List<
TimelineEntry< entries, required List<T> >TimelineDependency> dependencies, required TimelineDependencyNodeBuilder<T> itemBuilder, TimelineController<T> ? timelineController, TimelineEntryCallback<T> ? onEntryTap, TimelineThemeData? theme, double nodeWidth = 260, double nodeHeight = 126, double horizontalGap = 92, double verticalGap = 24, EdgeInsets padding = const EdgeInsets.all(28), double minScale = 0.45, double maxScale = 2.4, bool panEnabled = true, bool scaleEnabled = true, Key? key}) -
const
Properties
-
dependencies
→ List<
TimelineDependency> -
final
-
entries
→ List<
TimelineEntry< T> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalGap → double
-
final
-
itemBuilder
→ TimelineDependencyNodeBuilder<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxScale → double
-
final
- minScale → double
-
final
- nodeHeight → double
-
final
- nodeWidth → double
-
final
-
onEntryTap
→ TimelineEntryCallback<
T> ? -
final
- padding → EdgeInsets
-
final
- panEnabled → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleEnabled → bool
-
final
- theme → TimelineThemeData?
-
final
-
timelineController
→ TimelineController<
T> ? -
final
- verticalGap → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited