NeonPlannerSnapTargetKind enum
Type of snap target.
Values
- grid → const NeonPlannerSnapTargetKind
-
Regular minute grid.
- entryStart → const NeonPlannerSnapTargetKind
-
Start of a neighboring event.
- entryEnd → const NeonPlannerSnapTargetKind
-
End of a neighboring event.
- currentTime → const NeonPlannerSnapTargetKind
-
Current-time marker.
- custom → const NeonPlannerSnapTargetKind
-
Application-defined marker.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NeonPlannerSnapTargetKind> - A constant List of the values in this enum, in order of their declaration.