NeonTimelineLayout enum

Placement strategy for the rail and the two content areas.

Inheritance
Available extensions

Values

start → const NeonTimelineLayout

Put the rail at the logical start edge and all content after it.

center → const NeonTimelineLayout

Put the rail between opposite and primary content.

end → const NeonTimelineLayout

Put the rail at the logical end edge and all content before it.

alternating → const NeonTimelineLayout

Alternate primary content around a centered rail.

adaptive → const NeonTimelineLayout

Use center when wide and start below the adaptive breakpoint.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NeonTimelineLayout>
A constant List of the values in this enum, in order of their declaration.