ResourceTimelineView<T> class

Multi-resource planning board for people, rooms, machines, and teams.

Entries are indexed by resource once. Each row uses the O(n log n) overlap layout engine and a static grid painter. No animation or timer is created.

Inheritance

Constructors

ResourceTimelineView({required List<TimelineResource> resources, required List<TimelineEntry<T>> entries, required DateTime selectedDate, required TimelineResourceEntryBuilder<T> itemBuilder, TimelineResourceHeaderBuilder? resourceHeaderBuilder, TimelineThemeData? theme, TimelineController<T>? timelineController, TimelineEntryCallback<T>? onEntryTap, TimelineInteractionConfig interactions = const TimelineInteractionConfig(), Object? dataRevision, int startHour = 6, int endHour = 22, double pixelsPerMinute = 1.2, double rowHeight = 112, double resourceColumnWidth = 190, double minimumEntryHeight = 28, double entryGap = 4, bool showCapacityConflicts = true, bool showHalfHourLines = true, bool showTimeHeader = true, double timeHeaderHeight = 48, String? resourceHeaderLabel, ScrollController? verticalController, ScrollController? horizontalController, WidgetBuilder? emptyBuilder, DateTime? now, Key? key})
const

Properties

dataRevision Object?
final
emptyBuilder WidgetBuilder?
final
endHour int
final
entries List<TimelineEntry<T>>
final
entryGap double
final
hashCode int
The hash code for this object.
no setterinherited
horizontalController ScrollController?
final
interactions TimelineInteractionConfig
final
itemBuilder TimelineResourceEntryBuilder<T>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minimumEntryHeight double
final
now DateTime?
final
onEntryTap TimelineEntryCallback<T>?
final
pixelsPerMinute double
final
resourceColumnWidth double
final
resourceHeaderBuilder TimelineResourceHeaderBuilder?
final
resourceHeaderLabel String?
final
resources List<TimelineResource>
final
rowHeight double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDate DateTime
final
showCapacityConflicts bool
final
showHalfHourLines bool
final
showTimeHeader bool
final
startHour int
final
theme TimelineThemeData?
final
timeHeaderHeight double
final
timelineController TimelineController<T>?
final
verticalController ScrollController?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited