StructuredTimelineEntrySegment<T> class

Annotations

Constructors

StructuredTimelineEntrySegment({required TimelineEntry<T> entry, required DateTime viewportStart, required DateTime viewportEnd, required DateTime visibleStart, required DateTime visibleEnd, required TimelineEntrySegmentType type})
const

Properties

continuesAfter bool
no setter
continuesBefore bool
no setter
entry TimelineEntry<T>
final
hashCode int
The hash code for this object.
no setterinherited
originalDuration Duration
no setter
originalEnd DateTime
no setter
originalStart DateTime
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TimelineEntrySegmentType
final
viewportEnd DateTime
final
viewportStart DateTime
final
visibleDuration Duration
no setter
visibleEnd DateTime
final
visibleStart DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited