StructuredTimelineExperience class

Interaction and presentation defaults for the 10.x Structured timeline.

The object is intentionally independent from application state. Hosts may use a preset and override only the parts that matter to their product.

Annotations

Constructors

StructuredTimelineExperience({Duration dragActivationDelay = const Duration(milliseconds: 280), bool showDragScrim = true, bool showSnapGuide = true, bool showDropSlot = true, bool showConflictPreview = true, bool magnetizeToNeighbors = true, bool preferConflictFreeDrop = true, Duration magnetDistance = const Duration(minutes: 8), double dragLiftScale = 1.045, double dragElevation = 24, double placeholderOpacity = 0.16, double scrimOpacity = 0.035, Duration edgeScrollFrameInterval = const Duration(milliseconds: 16), bool selectOnDragStart = true, bool hideFloatingActionWhileDragging = true, bool announceDragChanges = true})
const
StructuredTimelineExperience.batterySaver()
const
StructuredTimelineExperience.delight()
const
StructuredTimelineExperience.precise()
const

Properties

announceDragChanges bool
final
dragActivationDelay Duration
final
dragElevation double
final
dragLiftScale double
final
edgeScrollFrameInterval Duration
final
hashCode int
The hash code for this object.
no setterinherited
hideFloatingActionWhileDragging bool
final
magnetDistance Duration
final
magnetizeToNeighbors bool
final
placeholderOpacity double
final
preferConflictFreeDrop bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrimOpacity double
final
selectOnDragStart bool
final
showConflictPreview bool
final
showDragScrim bool
final
showDropSlot bool
final
showSnapGuide bool
final

Methods

copyWith({Duration? dragActivationDelay, bool? showDragScrim, bool? showSnapGuide, bool? showDropSlot, bool? showConflictPreview, bool? magnetizeToNeighbors, bool? preferConflictFreeDrop, Duration? magnetDistance, double? dragLiftScale, double? dragElevation, double? placeholderOpacity, double? scrimOpacity, Duration? edgeScrollFrameInterval, bool? selectOnDragStart, bool? hideFloatingActionWhileDragging, bool? announceDragChanges}) StructuredTimelineExperience
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited