StructuredTimelineMoveDetails<T> class

Annotations

Constructors

StructuredTimelineMoveDetails({required TimelineDayEntry<T> item, required TimelineDropResult<T> result})
const

Properties

entry TimelineEntry<T>
no setter
hashCode int
The hash code for this object.
no setterinherited
item TimelineDayEntry<T>
final
preview TimelineReschedulePreview<T>
no setter
result TimelineDropResult<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited