StructuredTimelineOperation class abstract interface

Reversible timeline operation used for drag, resize and batch updates.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
id Object
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply() FutureOr<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revert() FutureOr<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited