Reversible application command used by direct manipulation and shortcuts.
Properties
Methods
-
execute(
) → FutureOr< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
undo(
) → FutureOr< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited