TimelineController<T> class

Host-owned controller for selection, zoom, focus, and visible-range state.

Inheritance

Constructors

TimelineController({Iterable<Object> selectedIds = const <Object>[], double zoom = 1, TimelineDateRange? visibleRange, Object? focusedId})

Properties

focusedId Object?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasSelection bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIds Set<Object>
no setter
visibleRange TimelineDateRange?
no setter
zoom double
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
batch(VoidCallback updates) → void
Coalesces multiple changes into one notification.
clearSelection() → void
dispose() → void
Discards any resources used by the object.
inherited
isFocused(Object id) bool
isSelected(Object id) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
panVisibleRange(Duration offset) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
select(Object id, {TimelineSelectionMode mode = TimelineSelectionMode.single}) → void
selectOnly(Object id) → void
selectRange({required List<Object> orderedIds, required Object startId, required Object endId, bool addToSelection = false}) → void
setFocusedId(Object? id) → void
setSelection(Iterable<Object> ids) → void
setVisibleRange(TimelineDateRange? range) → void
setZoom(double value) → void
toggle(Object id) → void
toString() String
A string representation of this object.
inherited
zoomBy(double factor) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited