TimelineDataSource<T> class
abstract
Backend-independent source contract for future paged and live adapters.
- Inheritance
-
- Object
- Listenable
- TimelineDataSource
- Implementers
Constructors
Properties
-
entries
→ List<
TimelineEntry< T> > -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- revision → Object?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited