TimelineInteractionConfig class

Interaction policy shared by schedule and planner views.

Annotations

Constructors

TimelineInteractionConfig({bool enabled = true, TimelineSelectionMode selectionMode = TimelineSelectionMode.single, bool enableDragging = true, bool enableResizing = false, bool enableKeyboard = true, bool enableHaptics = true, int snapMinutes = 5, Duration longPressDelay = const Duration(milliseconds: 420), double movementThreshold = 8})
const

Properties

enabled bool
final
enableDragging bool
final
enableHaptics bool
final
enableKeyboard bool
final
enableResizing bool
final
hashCode int
The hash code for this object.
no setterinherited
longPressDelay Duration
final
movementThreshold double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionMode TimelineSelectionMode
final
snapMinutes int
final

Methods

copyWith({bool? enabled, TimelineSelectionMode? selectionMode, bool? enableDragging, bool? enableResizing, bool? enableKeyboard, bool? enableHaptics, int? snapMinutes, Duration? longPressDelay, double? movementThreshold}) TimelineInteractionConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited