TimelineMatrixView<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TimelineMatrixView
Constructors
-
TimelineMatrixView({required List<
TimelineEntry< entries, required List<T> >TimelineResource> resources, required DateTime rangeStart, required DateTime rangeEnd, required String titleBuilder(TimelineEntry<T> entry), Duration slotDuration = const Duration(hours: 1), double slotWidth = 88, double rowHeight = 84, double resourceHeaderWidth = 190, ValueChanged<TimelineEntry< ? onEntryTap, String timeLabelBuilder(DateTime value)?, EdgeInsetsGeometry padding = const EdgeInsets.all(14), Key? key})T> > -
const
Properties
-
entries
→ List<
TimelineEntry< T> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onEntryTap
→ ValueChanged<
TimelineEntry< ?T> > -
final
- padding → EdgeInsetsGeometry
-
final
- rangeEnd → DateTime
-
final
- rangeStart → DateTime
-
final
- resourceHeaderWidth → double
-
final
-
resources
→ List<
TimelineResource> -
final
- rowHeight → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slotDuration → Duration
-
final
- slotWidth → double
-
final
- timeLabelBuilder → String Function(DateTime value)?
-
final
-
titleBuilder
→ String Function(TimelineEntry<
T> entry) -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited