TimelineMotionConfig class

Motion policy. It never changes layout or data semantics.

Annotations

Constructors

TimelineMotionConfig({bool enabled = true, int framesPerSecond = 24, int maxAnimatedEntries = 1, bool pauseWhileScrolling = true, bool respectReducedMotion = true, Duration duration = const Duration(milliseconds: 320), Curve curve = Curves.easeOutCubic})
const
TimelineMotionConfig.disabled()
const

Properties

curve Curve
final
duration Duration
final
enabled bool
final
framesPerSecond int
final
hashCode int
The hash code for this object.
no setterinherited
maxAnimatedEntries int
final
pauseWhileScrolling bool
final
respectReducedMotion bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? enabled, int? framesPerSecond, int? maxAnimatedEntries, bool? pauseWhileScrolling, bool? respectReducedMotion, Duration? duration, Curve? curve}) TimelineMotionConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited