UltimateTimelineCommand<T> class abstract

Typed reversible command for the 12.x timeline.

Implemented types
Implementers

Constructors

UltimateTimelineCommand()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id Object
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply() FutureOr<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revert() FutureOr<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited