UltimateTimelineHistoryController<T> class
Typed facade over the bounded, async-safe 11.x history implementation.
- Inheritance
-
- Object
- ChangeNotifier
- StructuredTimelineInteractionHistory
- UltimateTimelineHistoryController
Constructors
- UltimateTimelineHistoryController({int capacity = 50})
Properties
- busy → bool
-
no setterinherited
- canRedo → bool
-
no setterinherited
- canUndo → bool
-
no setterinherited
- capacity → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clear(
) → void -
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
execute(
StructuredTimelineOperation operation) → Future< void> -
inherited
-
executeCommand(
UltimateTimelineCommand< T> command) → Future<void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
redo(
) → Future< void> -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
undo(
) → Future< void> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited