UltimateTimelineMoveCommand<T> class

Reversible move command. Persistence remains owned by the host callback.

Inheritance
Annotations

Constructors

UltimateTimelineMoveCommand({required TimelineEntry<T> entry, required DateTime fromStart, required DateTime fromEnd, required DateTime toStart, required DateTime toEnd, required UltimateTimelineMutation<T> mutate})
const

Properties

entry TimelineEntry<T>
final
fromEnd DateTime
final
fromStart DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id Object
no setteroverride
mutate UltimateTimelineMutation<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toEnd DateTime
final
toStart DateTime
final

Methods

apply() FutureOr<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revert() FutureOr<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited