UltimateTimelineSnapConfig class

Immutable tuning for weighted snapping and anti-flicker hysteresis.

Annotations

Constructors

UltimateTimelineSnapConfig({Duration grid = const Duration(minutes: 5), Duration magnetDistance = const Duration(minutes: 12), Duration hysteresis = const Duration(minutes: 2), Duration minimumSeparation = Duration.zero, bool preferConflictFree = true, bool includeCurrentTime = false})
const

Properties

grid Duration
final
hashCode int
The hash code for this object.
no setterinherited
hysteresis Duration
final
includeCurrentTime bool
final
magnetDistance Duration
final
minimumSeparation Duration
final
preferConflictFree bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited