NeonTimelinePerformanceConfig class
Public performance policy shared by generic and planner timelines.
The policy never changes layout, colors, semantics, or public interaction. It only limits continuous motion and expensive rendering detail.
- Annotations
Constructors
- NeonTimelinePerformanceConfig({NeonTimelinePerformanceProfile profile = NeonTimelinePerformanceProfile.adaptive, int? motionFramesPerSecond, int? maxAnimatedEntries, bool? pauseMotionWhileScrolling, bool? enableBackdropBlur, bool? enableParallax, bool? enableParticles, double? cacheExtent, Duration? motionStartupDelay, NeonTimelineWebGlowStrategy webGlowStrategy = NeonTimelineWebGlowStrategy.adaptive, NeonTimelineRenderQuality? renderQuality})
-
const
- NeonTimelinePerformanceConfig.adaptive()
-
const
- NeonTimelinePerformanceConfig.balanced()
-
const
- NeonTimelinePerformanceConfig.batterySaver()
-
const
- NeonTimelinePerformanceConfig.highQuality()
-
const
Properties
- cacheExtent → double?
-
final
- enableBackdropBlur → bool?
-
final
- enableParallax → bool?
-
final
- enableParticles → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAnimatedEntries → int?
-
final
- motionFramesPerSecond → int?
-
final
- motionStartupDelay → Duration?
-
final
- pauseMotionWhileScrolling → bool?
-
final
- profile → NeonTimelinePerformanceProfile
-
final
- renderQuality → NeonTimelineRenderQuality?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webGlowStrategy → NeonTimelineWebGlowStrategy
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context, {required int itemCount}) → NeonTimelineResolvedPerformance -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited