StructuredTimelinePlanner<T> class

Convenience bridge from application-owned models directly to the Structured-style 7.x timeline.

Only one lifecycle-aware clock is created for the entire timeline. Set now to control the clock externally or set refreshInterval to zero to disable automatic refreshes.

Inheritance

Constructors

StructuredTimelinePlanner({required List<T> values, required TimelinePlannerEngine<T> engine, required DateTime selectedDate, Object? dataRevision, DateTime? now, Duration refreshInterval = const Duration(seconds: 30), TimelineDayPlanConfig dayConfig = const TimelineDayPlanConfig(), StructuredTimelineStyle? style, StructuredTimelineStrings strings = const StructuredTimelineStrings(), StructuredTimelineEntryCallback<T>? onEntryTap, StructuredTimelineEntryCallback<T>? onComplete, StructuredTimelineMoveCallback<T>? onMove, StructuredTimelineMoveCallback<T>? onDelete, StructuredTimelineGapCallback<T>? onInsert, StructuredTimelineCardBuilder<T>? cardBuilder, StructuredTimelineIconBuilder<T>? iconBuilder, StructuredTimelineTrailingBuilder<T>? trailingBuilder, StructuredTimelineTitleBuilder<T>? titleBuilder, StructuredTimelineSubtitleBuilder<T>? subtitleBuilder, StructuredTimelineProgressBuilder<T>? progressBuilder, StructuredTimelineTimeFormatter? timeFormatter, StructuredTimelineDurationFormatter? durationFormatter, ScrollController? scrollController, ScrollPhysics? physics, EdgeInsetsGeometry padding = const EdgeInsets.only(top: 8, bottom: 120), bool showInsightBanner = true, bool showCompletionToggle = true, bool showBoundaryGaps = false, bool enableDragging = true, bool enableDeleteTarget = false, StructuredTimelineInitialScroll initialScroll = StructuredTimelineInitialScroll.current, TimelineReschedulePolicy reschedulePolicy = const TimelineReschedulePolicy(), TimelineAutoScrollPolicy autoScrollPolicy = const TimelineAutoScrollPolicy(), WidgetBuilder? emptyBuilder, Key? key})
const

Properties

autoScrollPolicy TimelineAutoScrollPolicy
final
cardBuilder StructuredTimelineCardBuilder<T>?
final
dataRevision Object?
final
dayConfig TimelineDayPlanConfig
final
durationFormatter StructuredTimelineDurationFormatter?
final
emptyBuilder WidgetBuilder?
final
enableDeleteTarget bool
final
enableDragging bool
final
engine TimelinePlannerEngine<T>
final
hashCode int
The hash code for this object.
no setterinherited
iconBuilder StructuredTimelineCardBuilder<T>?
final
initialScroll StructuredTimelineInitialScroll
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
now DateTime?
final
onComplete StructuredTimelineEntryCallback<T>?
final
onDelete StructuredTimelineMoveCallback<T>?
final
onEntryTap StructuredTimelineEntryCallback<T>?
final
onInsert StructuredTimelineGapCallback<T>?
final
onMove StructuredTimelineMoveCallback<T>?
final
padding EdgeInsetsGeometry
final
physics ScrollPhysics?
final
progressBuilder StructuredTimelineProgressBuilder<T>?
final
refreshInterval Duration
final
reschedulePolicy TimelineReschedulePolicy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
selectedDate DateTime
final
showBoundaryGaps bool
final
showCompletionToggle bool
final
showInsightBanner bool
final
strings StructuredTimelineStrings
final
style StructuredTimelineStyle?
final
subtitleBuilder StructuredTimelineSubtitleBuilder<T>?
final
timeFormatter StructuredTimelineTimeFormatter?
final
titleBuilder StructuredTimelineTitleBuilder<T>?
final
trailingBuilder StructuredTimelineCardBuilder<T>?
final
values List<T>
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StructuredTimelinePlanner<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited