TimelineNormalizedEntry<T> class
- Annotations
Constructors
-
TimelineNormalizedEntry({required TimelineEntry<
T> entry, required int originalIndex, required DateTime start, required DateTime end, required DateTime originalStart, required DateTime originalEnd, required bool invalidRange, required bool isCurrent}) -
const
Properties
- duration → Duration
-
no setter
- end → DateTime
-
final
-
entry
→ TimelineEntry<
T> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidRange → bool
-
final
- isCurrent → bool
-
final
- originalEnd → DateTime
-
final
- originalIndex → int
-
final
- originalStart → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited