TimelineWeekPlanBuilder class
Builds the seven vertical day lanes seen in compact week planners while leaving every visual decision to the consuming application.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
build<
T> ({required List< TimelineEntry< entries, required DateTime selectedDate, DateTime? now, int firstWeekday = DateTime.monday, Duration anchorOffset = const Duration(hours: 23, minutes: 30), TimelineDayPlanConfig dayConfig = const TimelineDayPlanConfig()}) → TimelineWeekPlan<T> >T> -
buildFromIndex<
T> ({required TimelineTemporalIndex< T> index, required DateTime selectedDate, DateTime? now, int firstWeekday = DateTime.monday, Duration anchorOffset = const Duration(hours: 23, minutes: 30), TimelineDayPlanConfig dayConfig = const TimelineDayPlanConfig()}) → TimelineWeekPlan<T>